@@ -29,17 +29,15 @@ from . import (
     dto,
     exceptions,
     health,
-    logging,
+    log,
     openapi,
     orm,
     redis,
     repository,
-    response,
     sentry,
     service,
     settings,
     sqlalchemy_plugin,
-    static_files,
     worker,
 )
 from .init_plugin import ConfigureApp, PluginConfig
@@ -53,18 +51,16 @@ __all__ = [
     "dto",
     "exceptions",
     "health",
-    "logging",
+    "log",
     "openapi",
     "orm",
     "redis",
     "repository",
-    "response",
     "sentry",
     "service",
     "settings",
     "sqlalchemy_plugin",
-    "static_files",
     "worker",
 ]
 
-__version__ = "0.1.7"
+__version__ = "0.3.0"
