@@ -28,36 +28,42 @@ instantiation:
 
 The `PluginConfig` has switches to disable every aspect of the plugin behavior.
 """
-from typing import TYPE_CHECKING
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, TypeVar
 
 from pydantic import BaseModel
 from starlite.app import DEFAULT_CACHE_CONFIG, DEFAULT_OPENAPI_CONFIG
 from starlite.plugins.sql_alchemy import SQLAlchemyPlugin
+from starlite.response import Response
 
-from . import (
+from starlite_saqlalchemy import (
     cache,
     compression,
     dependencies,
     exceptions,
     http,
-    logging,
+    log,
     openapi,
     redis,
-    response,
     sentry,
     sqlalchemy_plugin,
-    static_files,
 )
-from .health import health_check
-from .repository.exceptions import RepositoryException
-from .service import ServiceException, make_service_callback
-from .worker import create_worker_instance
+from starlite_saqlalchemy.health import health_check
+from starlite_saqlalchemy.repository.exceptions import RepositoryException
+from starlite_saqlalchemy.serializer import default_serializer
+from starlite_saqlalchemy.service import ServiceException, make_service_callback
+from starlite_saqlalchemy.worker import create_worker_instance
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Sequence
+    from typing import Any
 
+    from saq.worker import Worker  # type:ignore[import]
     from starlite.config.app import AppConfig
+    from structlog.types import Processor
 
-    from starlite_saqlalchemy.worker import WorkerFunction
+T = TypeVar("T")
 
 
 class PluginConfig(BaseModel):
@@ -70,7 +76,10 @@ class PluginConfig(BaseModel):
     application.
     """
 
-    worker_functions: "list[WorkerFunction | tuple[str, WorkerFunction]]" = []
+    # why isn't the callback defined here?
+    worker_functions: list[Callable[..., Any] | tuple[str, Callable[..., Any]]] = [
+        (make_service_callback.__qualname__, make_service_callback)
+    ]
     """
     Queue worker functions.
     """
@@ -129,11 +138,6 @@ class PluginConfig(BaseModel):
     Set the SQLAlchemy plugin on the application. Adds the plugin to
     [`AppConfig.plugins`][starlite.config.app.AppConfig.plugins].
     """
-    do_static_files: bool = True
-    """
-    Set the static files config object to
-    [`AppConfig.static_files_config`][starlite.config.app.AppConfig.static_files_config].
-    """
     do_worker: bool = True
     """
     Configure the async worker on the application. This action instantiates a worker instance and
@@ -141,6 +145,20 @@ class PluginConfig(BaseModel):
     [`AppConfig.on_shutdown`][starlite.config.app.AppConfig.on_shutdown] that manage the lifecycle
     of the `SAQ` worker.
     """
+    serializer: Callable[[Any], Any] = default_serializer
+    """
+    The serializer callable that is used by the custom [`Response`][starlite.response.Response]
+    class that is created.
+    If [`AppConfig.response_class`][starlite.config.app.AppConfig.response_class] is not `None`,
+    this is ignored.
+    If
+    [`PluginConfig.do_response_class`][starlite_saqlalchemy.init_plugin.PluginConfig.do_response_class]
+    is `False`, this is ignored.
+    """
+    # the addition of the health check filter processor makes mypy think `log.default_processors` is
+    # list[object].. seems typed correctly to me :/
+    log_processors: Sequence[Processor] = log.default_processors  # type:ignore[assignment]
+    """Chain of structlog log processors."""
 
 
 class ConfigureApp:
@@ -150,10 +168,14 @@ class ConfigureApp:
         config: Provide a config object to customize the behavior of the plugin.
     """
 
+    __slots__ = ("config", "worker_instance")
+
+    worker_instance: Worker
+
     def __init__(self, config: PluginConfig = PluginConfig()) -> None:
         self.config = config
 
-    def __call__(self, app_config: "AppConfig") -> "AppConfig":
+    def __call__(self, app_config: AppConfig) -> AppConfig:
         """Entrypoint to the app config plugin.
 
         Receives the [`AppConfig`][starlite.config.app.AppConfig] object and modifies it.
@@ -174,13 +196,12 @@ class ConfigureApp:
         self.configure_response_class(app_config)
         self.configure_sentry(app_config)
         self.configure_sqlalchemy_plugin(app_config)
-        self.configure_static_files(app_config)
         self.configure_worker(app_config)
 
         app_config.on_shutdown.extend([http.Client.close, redis.client.close])
         return app_config
 
-    def configure_after_exception(self, app_config: "AppConfig") -> None:
+    def configure_after_exception(self, app_config: AppConfig) -> None:
         """Add the logging after exception hook handler.
 
         Args:
@@ -191,7 +212,7 @@ class ConfigureApp:
                 app_config.after_exception = [app_config.after_exception]
             app_config.after_exception.append(exceptions.after_exception_hook_handler)
 
-    def configure_cache(self, app_config: "AppConfig") -> None:
+    def configure_cache(self, app_config: AppConfig) -> None:
         """Configure the application cache.
 
         We only overwrite if [`DEFAULT_CACHE_CONFIG`][starlite.app.DEFAULT_CACHE_CONFIG] is the
@@ -203,7 +224,7 @@ class ConfigureApp:
         if self.config.do_cache and app_config.cache_config is DEFAULT_CACHE_CONFIG:
             app_config.cache_config = cache.config
 
-    def configure_collection_dependencies(self, app_config: "AppConfig") -> None:
+    def configure_collection_dependencies(self, app_config: AppConfig) -> None:
         """Add the required [`Provide`][starlite.datastructures.Provide]
         instances to the app dependency mapping.
 
@@ -216,7 +237,7 @@ class ConfigureApp:
             for key, value in dependencies.create_collection_dependencies().items():
                 app_config.dependencies.setdefault(key, value)
 
-    def configure_compression(self, app_config: "AppConfig") -> None:
+    def configure_compression(self, app_config: AppConfig) -> None:
         """Configure application compression.
 
         No-op if [`AppConfig.compression_config`][starlite.config.app.AppConfig.compression_config]
@@ -228,7 +249,7 @@ class ConfigureApp:
         if self.config.do_compression and app_config.compression_config is None:
             app_config.compression_config = compression.config
 
-    def configure_exception_handlers(self, app_config: "AppConfig") -> None:
+    def configure_exception_handlers(self, app_config: AppConfig) -> None:
         """Add the handlers that translate service and repository exceptions
         into HTTP exceptions.
 
@@ -247,7 +268,7 @@ class ConfigureApp:
             ServiceException, exceptions.service_exception_to_http_response
         )
 
-    def configure_health_check(self, app_config: "AppConfig") -> None:
+    def configure_health_check(self, app_config: AppConfig) -> None:
         """Adds the health check controller.
 
         Args:
@@ -256,7 +277,7 @@ class ConfigureApp:
         if self.config.do_health_check:
             app_config.route_handlers.append(health_check)
 
-    def configure_logging(self, app_config: "AppConfig") -> None:
+    def configure_logging(self, app_config: AppConfig) -> None:
         """Configures application logging if it has not already been
         configured.
 
@@ -264,9 +285,13 @@ class ConfigureApp:
             app_config: The Starlite application config object.
         """
         if self.config.do_logging and app_config.logging_config is None:
-            app_config.logging_config = logging.config
+            app_config.on_startup.append(lambda: log.configure(self.config.log_processors))
+            app_config.logging_config = log.config
+            app_config.middleware.append(log.controller.middleware_factory)
+            app_config.before_send = self._ensure_list(app_config.before_send)
+            app_config.before_send.append(log.controller.BeforeSendHandler())
 
-    def configure_openapi(self, app_config: "AppConfig") -> None:
+    def configure_openapi(self, app_config: AppConfig) -> None:
         """Configures the OpenAPI docs if they have not already been
         configured.
 
@@ -278,7 +303,7 @@ class ConfigureApp:
         if self.config.do_openapi and app_config.openapi_config is DEFAULT_OPENAPI_CONFIG:
             app_config.openapi_config = openapi.config
 
-    def configure_response_class(self, app_config: "AppConfig") -> None:
+    def configure_response_class(self, app_config: AppConfig) -> None:
         """Add the custom response class.
 
         No-op if the [`AppConfig.response_class`][starlite.config.app.AppConfig.response_class]
@@ -288,9 +313,11 @@ class ConfigureApp:
             app_config: The Starlite application config object.
         """
         if self.config.do_response_class and app_config.response_class is None:
-            app_config.response_class = response.Response
+            app_config.response_class = type(
+                "Response", (Response,), {"serializer": staticmethod(self.config.serializer)}
+            )
 
-    def configure_sentry(self, app_config: "AppConfig") -> None:
+    def configure_sentry(self, app_config: AppConfig) -> None:
         """Add handler to configure Sentry integration.
 
         Args:
@@ -299,7 +326,7 @@ class ConfigureApp:
         if self.config.do_sentry:
             app_config.on_startup.append(sentry.configure)
 
-    def configure_sqlalchemy_plugin(self, app_config: "AppConfig") -> None:
+    def configure_sqlalchemy_plugin(self, app_config: AppConfig) -> None:
         """Configure `SQLAlchemy` for the application.
 
         Adds a configured [`SQLAlchemyPlugin`][starlite.plugins.sql_alchemy.SQLAlchemyPlugin] to
@@ -311,20 +338,7 @@ class ConfigureApp:
         if self.config.do_sqlalchemy_plugin:
             app_config.plugins.append(SQLAlchemyPlugin(config=sqlalchemy_plugin.config))
 
-    def configure_static_files(self, app_config: "AppConfig") -> None:
-        """Configure static files for the application.
-
-        No-op if
-        [`AppConfig.static_files_config`][starlite.config.app.AppConfig.static_files_config] is not
-        `None`.
-
-        Args:
-            app_config: The Starlite application config object.
-        """
-        if self.config.do_static_files and app_config.static_files_config is not None:
-            app_config.static_files_config = static_files.config
-
-    def configure_worker(self, app_config: "AppConfig") -> None:
+    def configure_worker(self, app_config: AppConfig) -> None:
         """Configure the `SAQ` async worker.
 
         No-op if there are no worker functions set on
@@ -333,10 +347,17 @@ class ConfigureApp:
         Args:
             app_config: The Starlite application config object.
         """
-        if self.config.do_worker and self.config.worker_functions:
-            self.config.worker_functions.append(
-                (make_service_callback.__qualname__, make_service_callback)
-            )
-            worker_instance = create_worker_instance(self.config.worker_functions)
-            app_config.on_shutdown.append(worker_instance.stop)
+        if self.config.do_worker:
+            worker_kwargs: dict[str, Any] = {"functions": self.config.worker_functions}
+            if self.config.do_logging:
+                worker_kwargs["before_process"] = log.worker.before_process
+                worker_kwargs["after_process"] = log.worker.after_process
+            worker_instance = create_worker_instance(**worker_kwargs)
             app_config.on_startup.append(worker_instance.on_app_startup)
+            app_config.on_shutdown.append(worker_instance.stop)
+
+    @staticmethod
+    def _ensure_list(item: list[T] | T) -> list[T]:
+        if isinstance(item, list):
+            return item
+        return [] if item is None else [item]
